/***************************************************************************
**
**  This file is part of QGpCoreTools.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2010-09-11
**  Copyright: 2010-2019
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#include "StandardStream.h"

namespace QGpCoreTools {

  /*!
    \class StandardStream StandardStream.h
    \brief A stream directed to stdout or stderr

    Full description of class still missing
  */

  StandardStream::StandardStream(FILE * fileHandle)
    : AbstractStream(), _s(fileHandle, QIODevice::WriteOnly)
  {
#if(QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
    _s.setEncoding(QStringConverter::Utf8);
#else
    _s.setCodec("UTF-8");
#endif
  }

} // namespace QGpCoreTools
